@@ -67,8 +67,8 @@ func TestObserveUserClientCABundle(t *testing.T) {
 			}
 			synced := map[string]string{}
 			listers := configobservation.Listers{
-				APIServerLister: configlistersv1.NewAPIServerLister(indexer),
-				ResourceSync:    &mockResourceSyncer{t: t, synced: synced},
+				APIServerLister_: configlistersv1.NewAPIServerLister(indexer),
+				ResourceSync:     &mockResourceSyncer{t: t, synced: synced},
 			}
 			result, errs := ObserveUserClientCABundle(listers, events.NewInMemoryRecorder(t.Name()), tc.existing)
 			if len(errs) > 0 {
@@ -147,6 +147,10 @@ func TestObserveNamedCertificates(t *testing.T) {
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.key",
 						},
+						map[string]interface{}{
+							"certFile": "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.crt",
+							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.key",
+						},
 					},
 				},
 			},
@@ -191,6 +195,10 @@ func TestObserveNamedCertificates(t *testing.T) {
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.key",
 						},
+						map[string]interface{}{
+							"certFile": "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.crt",
+							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.key",
+						},
 						map[string]interface{}{
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/user-serving-cert-000/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/user-serving-cert-000/tls.key",
@@ -239,6 +247,10 @@ func TestObserveNamedCertificates(t *testing.T) {
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.key",
 						},
+						map[string]interface{}{
+							"certFile": "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.crt",
+							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.key",
+						},
 						map[string]interface{}{
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/user-serving-cert-000/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/user-serving-cert-000/tls.key",
@@ -289,6 +301,10 @@ func TestObserveNamedCertificates(t *testing.T) {
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.key",
 						},
+						map[string]interface{}{
+							"certFile": "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.crt",
+							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.key",
+						},
 						map[string]interface{}{
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/user-serving-cert-000/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/user-serving-cert-000/tls.key",
@@ -346,6 +362,10 @@ func TestObserveNamedCertificates(t *testing.T) {
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/internal-loadbalancer-serving-certkey/tls.key",
 						},
+						map[string]interface{}{
+							"certFile": "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.crt",
+							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/localhost-recovery-serving-certkey/tls.key",
+						},
 						map[string]interface{}{
 							"certFile": "/etc/kubernetes/static-pod-certs/secrets/user-serving-cert-000/tls.crt",
 							"keyFile":  "/etc/kubernetes/static-pod-certs/secrets/user-serving-cert-000/tls.key",
@@ -434,8 +454,8 @@ func TestObserveNamedCertificates(t *testing.T) {
 
 			synced := map[string]string{}
 			listers := configobservation.Listers{
-				APIServerLister: configlistersv1.NewAPIServerLister(indexer),
-				ResourceSync:    &mockResourceSyncer{t: t, synced: synced},
+				APIServerLister_: configlistersv1.NewAPIServerLister(indexer),
+				ResourceSync:     &mockResourceSyncer{t: t, synced: synced},
 			}
 			result, errs := ObserveNamedCertificates(listers, events.NewInMemoryRecorder(t.Name()), tc.existing)
 			if tc.expectErrs && len(errs) == 0 {
