@@ -4,11 +4,12 @@ import (
 	"k8s.io/client-go/tools/cache"
 
 	configinformers "github.com/openshift/client-go/config/informers/externalversions"
-
 	"github.com/openshift/library-go/pkg/operator/configobserver"
+	libgoapiserver "github.com/openshift/library-go/pkg/operator/configobserver/apiserver"
 	"github.com/openshift/library-go/pkg/operator/configobserver/cloudprovider"
 	"github.com/openshift/library-go/pkg/operator/configobserver/featuregates"
 	"github.com/openshift/library-go/pkg/operator/configobserver/proxy"
+	encryption "github.com/openshift/library-go/pkg/operator/encryption/observer"
 	"github.com/openshift/library-go/pkg/operator/events"
 	"github.com/openshift/library-go/pkg/operator/resourcesynccontroller"
 	"github.com/openshift/library-go/pkg/operator/v1helpers"
@@ -20,7 +21,6 @@ import (
 	"github.com/openshift/cluster-kube-apiserver-operator/pkg/operator/configobservation/images"
 	"github.com/openshift/cluster-kube-apiserver-operator/pkg/operator/configobservation/network"
 	"github.com/openshift/cluster-kube-apiserver-operator/pkg/operator/configobservation/scheduler"
-
 	"github.com/openshift/cluster-kube-apiserver-operator/pkg/operator/operatorclient"
 )
 
@@ -42,9 +42,11 @@ func NewConfigObserver(
 		operatorclient.OperatorNamespace,
 	}
 
-	configMapPreRunCacheSynced := []cache.InformerSynced{}
+	preRunCacheSynced := []cache.InformerSynced{}
 	for _, ns := range interestingNamespaces {
-		configMapPreRunCacheSynced = append(configMapPreRunCacheSynced, kubeInformersForNamespaces.InformersFor(ns).Core().V1().ConfigMaps().Informer().HasSynced)
+		preRunCacheSynced = append(preRunCacheSynced,
+			kubeInformersForNamespaces.InformersFor(ns).Core().V1().ConfigMaps().Informer().HasSynced,
+		)
 	}
 
 	c := &ConfigObserver{
@@ -52,7 +54,7 @@ func NewConfigObserver(
 			operatorClient,
 			eventRecorder,
 			configobservation.Listers{
-				APIServerLister:       configInformer.Config().V1().APIServers().Lister(),
+				APIServerLister_:      configInformer.Config().V1().APIServers().Lister(),
 				AuthConfigLister:      configInformer.Config().V1().Authentications().Lister(),
 				FeatureGateLister_:    configInformer.Config().V1().FeatureGates().Lister(),
 				ImageConfigLister:     configInformer.Config().V1().Images().Lister(),
@@ -62,13 +64,15 @@ func NewConfigObserver(
 				SchedulerLister:       configInformer.Config().V1().Schedulers().Lister(),
 
 				ConfigmapLister:              kubeInformersForNamespaces.ConfigMapLister(),
+				SecretLister_:                kubeInformersForNamespaces.InformersFor(operatorclient.TargetNamespace).Core().V1().Secrets().Lister(),
 				OpenshiftEtcdEndpointsLister: kubeInformersForNamespaces.InformersFor("openshift-etcd").Core().V1().Endpoints().Lister(),
 
 				ResourceSync: resourceSyncer,
-				PreRunCachesSynced: append(configMapPreRunCacheSynced,
+				PreRunCachesSynced: append(preRunCacheSynced,
 					operatorClient.Informer().HasSynced,
 
 					kubeInformersForNamespaces.InformersFor("openshift-etcd").Core().V1().Endpoints().Informer().HasSynced,
+					kubeInformersForNamespaces.InformersFor(operatorclient.TargetNamespace).Core().V1().Secrets().Informer().HasSynced,
 
 					configInformer.Config().V1().APIServers().Informer().HasSynced,
 					configInformer.Config().V1().Authentications().Informer().HasSynced,
@@ -86,7 +90,13 @@ func NewConfigObserver(
 			apiserver.ObserveNamedCertificates,
 			apiserver.ObserveUserClientCABundle,
 			apiserver.ObserveAdditionalCORSAllowedOrigins,
+			libgoapiserver.ObserveTLSSecurityProfile,
 			auth.ObserveAuthMetadata,
+			encryption.NewEncryptionConfigObserver(
+				operatorclient.TargetNamespace,
+				// static path at which we expect to find the encryption config secret
+				"/etc/kubernetes/static-pod-resources/secrets/encryption-config/encryption-config",
+			),
 			etcd.ObserveStorageURLs,
 			cloudprovider.NewCloudProviderObserver(
 				"openshift-kube-apiserver",
